==> alfresco-repository-16.37-sources.jar: org/alfresco/opencmis/mapping/FixedValueProperty.java <==
/*
 * #%L
 * Alfresco Repository
 * %%
 * Copyright (C) 2005 - 2016 Alfresco Software Limited
 * %%
 * This file is part of the Alfresco software. 
 * If the software was purchased under a paid Alfresco license, the terms of 
 * the paid license agreement will prevail.  Otherwise, the software is 
 * provided under the following open source license terms:
 * 
 * Alfresco is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Alfresco is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License
 * along with Alfresco. If not, see <http://www.gnu.org/licenses/>.
 * #L%
 */
package org.alfresco.opencmis.mapping;

import java.io.Serializable;

import org.alfresco.opencmis.CMISConnector;
import org.alfresco.opencmis.dictionary.CMISNodeInfo;
import org.alfresco.service.ServiceRegistry;

/**
 * Property accessor for fixed value mapping (eg to null, true, etc)
 * 
 * @author florian.mueller
 */
public class FixedValueProperty extends AbstractProperty
{
    private Serializable value;

    /**
     * Construct
     * 
     * @param serviceRegistry ServiceRegistry
     * @param connector CMISConnector
     * @param propertyName String
     * @param value Serializable
     */
    public FixedValueProperty(ServiceRegistry serviceRegistry, CMISConnector connector, String propertyName,
            Serializable value)
    {
        super(serviceRegistry, connector, propertyName);
        this.value = value;
    }

    public Serializable getValueInternal(CMISNodeInfo nodeInfo)
    {
        return value;
    }
}

==> alfresco-repository-26.1.0.21-sources.jar: org/alfresco/opencmis/mapping/FixedValueProperty.java <==
/*
 * #%L
 * Alfresco Repository
 * %%
 * Copyright (C) 2005 - 2016 Alfresco Software Limited
 * %%
 * This file is part of the Alfresco software. 
 * If the software was purchased under a paid Alfresco license, the terms of 
 * the paid license agreement will prevail.  Otherwise, the software is 
 * provided under the following open source license terms:
 * 
 * Alfresco is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Alfresco is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License
 * along with Alfresco. If not, see <http://www.gnu.org/licenses/>.
 * #L%
 */
package org.alfresco.opencmis.mapping;

import java.io.Serializable;

import org.alfresco.opencmis.CMISConnector;
import org.alfresco.opencmis.dictionary.CMISNodeInfo;
import org.alfresco.service.ServiceRegistry;

/**
 * Property accessor for fixed value mapping (eg to null, true, etc)
 * 
 * @author florian.mueller
 */
public class FixedValueProperty extends AbstractProperty
{
    private Serializable value;

    /**
     * Construct
     * 
     * @param serviceRegistry
     *            ServiceRegistry
     * @param connector
     *            CMISConnector
     * @param propertyName
     *            String
     * @param value
     *            Serializable
     */
    public FixedValueProperty(ServiceRegistry serviceRegistry, CMISConnector connector, String propertyName,
            Serializable value)
    {
        super(serviceRegistry, connector, propertyName);
        this.value = value;
    }

    public Serializable getValueInternal(CMISNodeInfo nodeInfo)
    {
        return value;
    }
}
